@@ -2,6 +2,7 @@ import requests
 import json
 from urllib.parse import urljoin
 from os import SEEK_SET
+from contextlib import suppress
 
 PRODUCTION_API_URL = "https://app.conviso.com.br"
 STAGING_API_URL = "https://homologa.conviso.com.br"
@@ -63,6 +64,14 @@ class Deploys(object):
                 'deploy[project][metrics][total_lines]': (None, total_lines),
             })
 
+        with suppress(TypeError):
+            metrics = kargs.get('metrics')
+            files.update({
+                'deploy[metrics][new_lines]': (None, metrics['added_lines']),
+                'deploy[metrics][removed_lines]': (None, metrics['deleted_lines']), # noqa
+                'deploy[metrics][changed_lines]': (None, metrics['changed_lines']), # noqa
+            })
+
         if diff_content:
             self._assert_filepointer_is_at_beginning(diff_content)
             diff_content_args = (
