@@ -50,11 +50,18 @@ def log_func(msg, new_line=True, clear=False):
     reports to flow. When --send-to-flow option is set the --project-code
     option is required"""
 )
+@click.option(
+    "--sastbox-tag",
+    default=SASTBox.DEFAULT_TAG,
+    required=False,
+    hidden=True,
+    envvar="FLOW_SASTBOX_TAG"
+)
 @help_option
 @pass_flow_context
 def run(
     flow_context, project_code, end_commit,
-    start_commit, repository_dir, send_to_flow
+    start_commit, repository_dir, send_to_flow, sastbox_tag
 ):
     '''
       This command will perform SAST analysis at the source code. The analysis
@@ -69,13 +76,14 @@ def run(
         end_commit,
         start_commit,
         repository_dir,
-        send_to_flow
+        send_to_flow,
+        sastbox_tag
     )
 
 
 def perform_command(
     flow_context, project_code, end_commit,
-    start_commit, repository_dir, send_to_flow
+    start_commit, repository_dir, send_to_flow, sastbox_tag
 ):
     if send_to_flow and not project_code:
         raise click.MissingParameter(
@@ -97,7 +105,7 @@ def perform_command(
 
         flow = flow_context.create_flow_api_client()
         token = flow.docker_registry.get_sast_token()
-        sastbox = SASTBox()
+        sastbox = SASTBox(sastbox_tag)
         log_func('Checking SASTBox authorization...')
         sastbox.login(token)
 
